@@ -9,7 +9,7 @@ use Scalar::Util   ();
 
 our @EXPORT_OK = qw(slurp_json spurt_json);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use constant JSON_XS => $ENV{JSON_SLURPER_NO_JSON_XS} ? do { require JSON::PP; undef }
   : eval { require Cpanel::JSON::XS; Cpanel::JSON::XS->VERSION('4.09'); 1 } ? 1
@@ -109,6 +109,10 @@ sub spurt_json (\[@$%]$;@) {
           : JSON::PP->new->utf8->pretty->canonical->allow_nonref->allow_blessed->convert_blessed->escape_slash;
     }
 
+    if (ref $data eq 'REF') {
+        $data = $$data;
+    }
+
     my $ext = (File::Basename::fileparse($filename, qr/\.[^.]*/xm))[2];
     $filename = "$filename.json" unless $ext;
 
